# Demo_It-analyze

[![PyPI - Version](https://img.shields.io/pypi/v/demo-it-analyze.svg)](https://pypi.org/project/demo-it-analyze)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/demo-it-analyze.svg)](https://pypi.org/project/demo-it-analyze)

-----

**Table of Contents**

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install demo-it-analyze
```

## License

`demo-it-analyze` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
